@@ -50,8 +50,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 #define INFO_MISC "/proc/misc"
 
-#define INFO_SCSI "/proc/scsi/scsi"
-
 #define MAXCOLUMNWIDTH 600
 
 bool GetInfo_ReadfromFile(QTreeWidget* tree, const char *FileName, const QChar& splitChar) {
@@ -158,10 +156,6 @@ bool GetInfo_IO_Ports(QTreeWidget* tree) {
 	return GetInfo_ReadfromFile(tree, INFO_IOPORTS, ':');
 }
 
-bool GetInfo_SCSI(QTreeWidget* tree) {
-	return GetInfo_ReadfromFile(tree, INFO_SCSI, 0);
-}
-
 bool GetInfo_XServer_and_Video(QTreeWidget* tree) {
 	return GetInfo_XServer_Generic(tree);
 }
