@@ -1,4 +1,3 @@
-
 /*
  *  soldevicetypes.h
  *
@@ -23,7 +22,7 @@
 #ifndef SOLDEVICETYPES
 #define SOLDEVICETYPES
 
-//kde 
+//kde
 #include <kdiskfreespaceinfo.h>
 
 #include "soldevice.h"
@@ -33,78 +32,74 @@ class QVListLayout;
 
 class SolProcessorDevice : public SolDevice
 {
-  
-  public:
+public:
     SolProcessorDevice(const Solid::DeviceInterface::Type &);
     SolProcessorDevice(QTreeWidgetItem *, const Solid::Device &);
     QVListLayout *infoPanelLayout() Q_DECL_OVERRIDE;
-    
-  private:
+
+private:
     void setDefaultDeviceText() Q_DECL_OVERRIDE;
     void setDefaultListing(const Solid::DeviceInterface::Type &) Q_DECL_OVERRIDE;
 };
 
-
 class SolStorageDevice : public SolDevice
 {
-  
-  public:   
-    enum storageChildren { CREATECHILDREN , NOCHILDREN };
-    
+public:
+    enum storageChildren {
+        CREATECHILDREN, NOCHILDREN
+    };
+
     SolStorageDevice(const Solid::DeviceInterface::Type &);
-    SolStorageDevice(QTreeWidgetItem *, const Solid::Device &, const storageChildren & = CREATECHILDREN);
+    SolStorageDevice(QTreeWidgetItem *, const Solid::Device &,
+                     const storageChildren & = CREATECHILDREN);
     QVListLayout *infoPanelLayout() Q_DECL_OVERRIDE;
-      
-  private:
+
+private:
     void setDefaultDeviceText() Q_DECL_OVERRIDE;
     void setDefaultListing(const Solid::DeviceInterface::Type &) Q_DECL_OVERRIDE;
 };
 
-class SolVolumeDevice : public SolDevice 
+class SolVolumeDevice : public SolDevice
 {
-
-  public:
+public:
     SolVolumeDevice(const Solid::DeviceInterface::Type &);
     SolVolumeDevice(QTreeWidgetItem *, const Solid::Device &);
     QVListLayout *infoPanelLayout() Q_DECL_OVERRIDE;
-    
-  private:
+
+private:
     void setDefaultListing(const Solid::DeviceInterface::Type &) Q_DECL_OVERRIDE;
 };
 
-class SolMediaPlayerDevice : public SolDevice 
+class SolMediaPlayerDevice : public SolDevice
 {
-
-  public:
+public:
     SolMediaPlayerDevice(const Solid::DeviceInterface::Type &);
     SolMediaPlayerDevice(QTreeWidgetItem *, const Solid::Device &);
     QVListLayout *infoPanelLayout() Q_DECL_OVERRIDE;
 
-  private:
+private:
     void setDefaultListing(const Solid::DeviceInterface::Type &) Q_DECL_OVERRIDE;
 };
 
-class SolCameraDevice : public SolDevice 
+class SolCameraDevice : public SolDevice
 {
-
-  public:
+public:
     SolCameraDevice(const Solid::DeviceInterface::Type &);
     SolCameraDevice(QTreeWidgetItem *, const Solid::Device &);
     QVListLayout *infoPanelLayout() Q_DECL_OVERRIDE;
-    
-  private:
+
+private:
     void setDefaultListing(const Solid::DeviceInterface::Type &) Q_DECL_OVERRIDE;
 };
 
-class SolBatteryDevice : public SolDevice 
+class SolBatteryDevice : public SolDevice
 {
-
-  public:
+public:
     SolBatteryDevice(const Solid::DeviceInterface::Type &);
     SolBatteryDevice(QTreeWidgetItem *, const Solid::Device &);
     QVListLayout *infoPanelLayout() Q_DECL_OVERRIDE;
-    
-  private:
+
+private:
     void setDefaultListing(const Solid::DeviceInterface::Type &) Q_DECL_OVERRIDE;
 };
 
