@@ -36,7 +36,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 class KInfoListWidget : public KCModule
 {
 public:
-  KInfoListWidget(const QString &_title, QWidget *parent, bool _getlistbox (QTreeWidget*) = NULL);
+  KInfoListWidget(const QString &_title, QWidget *parent, bool _getlistbox (QTreeWidget*) = nullptr);
 
   void load() Q_DECL_OVERRIDE;
   QString quickHelp() const Q_DECL_OVERRIDE;
