@@ -139,19 +139,21 @@ class KInfoCenter : public KXmlGuiWindow
         */
         void resetCondition();
 
-        KcmContainer *m_contain;
-        QSplitter *m_splitter;
+        void clearSearchLine();
 
-        QAction *m_aboutKcm;
-        QAction *m_searchAction;
-        QAction *m_moduleHelpAction;
-        KActionMenu *m_helpAction;
+        KcmContainer *m_contain = nullptr;
+        QSplitter *m_splitter = nullptr;
 
-        QWidget *m_cWidget;
-        KLineEdit *m_searchText;
+        QAction *m_aboutKcm = nullptr;
+        QAction *m_searchAction = nullptr;
+        QAction *m_moduleHelpAction = nullptr;
+        KActionMenu *m_helpAction = nullptr;
 
-        SidePanel *m_sideMenu;
-        ToolTipManager *m_toolTips;
+        QWidget *m_cWidget = nullptr;
+        KLineEdit *m_searchText = nullptr;
+
+        SidePanel *m_sideMenu = nullptr;
+        ToolTipManager *m_toolTips = nullptr;
 };
 
 #endif //INFOCENTER
