@@ -49,7 +49,7 @@ class SidePanel : public QTreeView
         *
         * @param parent objects parent
         */
-        SidePanel(QWidget *parent);
+        explicit SidePanel(QWidget *parent);
 
         /**
         * Destory SidePanel object
@@ -115,6 +115,9 @@ class SidePanel : public QTreeView
         */
         void resetSearchSlot();
 
+Q_SIGNALS:
+        void clearSearchLine();
+
     private:
 
         /**
